//
// ISR.hpp:
//	Interface Definition of class segaISR.
//
// Purpose:
//	Encapsulates functions that set up the interrupt
//	service routine and the functions actually
//	called by the ISR.
//
// Author(s): Mark Pflaging   C-serve  70233,1552
//	      Dave Stampe     Internet dstamp@watserv1.uwaterloo.ca
//
// Also see authorships in OOPGLOVE.DOC.
// Date:    5/15/92 - 9/21/92
//
#ifndef __ISR_HPP
#define __ISR_HPP

#include <stdlib.h>

class segaISR {
	// calibrated timer rate for vertical
	static unsigned int clock_rate;
	static unsigned int clock_rate_hi;
	static unsigned int clock_rate_lo;

	// counter to emulate 18.2 Hz tick
	static unsigned int divisor;

	// resync counter
	static int syncount;

	// incremented each frame (use for timing)
	static long int_timer;

	static void (* frame_interrupt_routine)();
	static void (* glove_interrupt_routine)();

	static int glovecount;
	// count of how many glove calls per frame
	static int glove_rate;
	// Interrupt rate.
	int i_rate;

	static void interrupt (*oldint)(...);	// old timer ISR vector

	int findSegaSpeed();		// "vertical hold" adjustment
	static void handleGlove();
	static void interrupt fastTimer(...);	// NEW TIMER ISR
	void initTimer(int speed);	// SET UP FAST TIMER
	static void ResetTimer(int * reglist);	// RESET PC TO NORMAL
	static void resetTimer() { segaISR::ResetTimer(NULL); }
public:
	segaISR(void(* glove_handler)() = NULL,
		void(* sega_switcher)() = NULL);
	// start 'er up!
	void run() { initTimer(i_rate); }
	~segaISR() { resetTimer(); }
};

#endif
